==> deepin-terminal_5.2.11.orig.tar.gz: deepin-terminal-5.2.11/3rdparty/terminalwidget/lib/translations/terminalwidget_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1279"/>
        <source>Size: XXX x XXX</source>
        <translation>Tamanho: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1291"/>
        <source>Size: %1 x %2</source>
        <translation>Tamanho: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3178"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;A saída foi &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt; suspensa&lt;/a&gt; ao premir Ctrl+S. Prima &lt;b&gt;Ctrl+Q&lt;/b&gt; para continuar.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1105"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Nenhum tradutor de teclado disponível. A informação necessária para converter a pressão da tecla nos caracteres a enviar ao terminal não existe.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>Esquema de cores sem nome</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>Esquema de cores acessível</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="538"/>
        <source>Open link</source>
        <translation>Abrir ligação</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="539"/>
        <source>Copy link</source>
        <translation>Copiar ligação</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="543"/>
        <source>Send email to...</source>
        <translation>Enviar um email a...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="544"/>
        <source>Copy email address</source>
        <translation>Copiar endereço de email</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="451"/>
        <source>Color Scheme Error</source>
        <translation>Erro no esquema de cores</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="452"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Não foi possível carregar o esquema de cores: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Diferenciar maiúsculas/minúsculas</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Expressão regular</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Realçar todas as ocorrências</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Barra de pesquisa</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Localizar:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>

==> deepin-terminal_5.9.51+dfsg.orig.tar.gz: deepin-terminal-5.9.51+dfsg/3rdparty/terminalwidget/lib/translations/terminalwidget_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1279"/>
        <source>Size: XXX x XXX</source>
        <translation>Tamanho: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1291"/>
        <source>Size: %1 x %2</source>
        <translation>Tamanho: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3178"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;A saída foi &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt; suspensa&lt;/a&gt; ao premir Ctrl+S. Prima &lt;b&gt;Ctrl+Q&lt;/b&gt; para continuar.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1105"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Nenhum tradutor de teclado disponível. A informação necessária para converter a pressão da tecla nos caracteres a enviar ao terminal não existe.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>Esquema de cores sem nome</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>Esquema de cores acessível</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="538"/>
        <source>Open link</source>
        <translation>Abrir ligação</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="539"/>
        <source>Copy link</source>
        <translation>Copiar ligação</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="543"/>
        <source>Send email to...</source>
        <translation>Enviar um email a...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="544"/>
        <source>Copy email address</source>
        <translation>Copiar endereço de email</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="451"/>
        <source>Color Scheme Error</source>
        <translation>Erro no esquema de cores</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="452"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Não foi possível carregar o esquema de cores: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Diferenciar maiúsculas/minúsculas</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Expressão regular</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Realçar todas as ocorrências</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Barra de pesquisa</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Localizar:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>
